"""Utilities for configuring ansible runtime environment."""

import os
from pathlib import Path


def get_cache_dir(project_dir: Path, *, isolated: bool = True) -> Path:
    """Compute cache directory to be used based on project path.

    Args:
        project_dir: Path to the project directory.
        isolated: Whether to use isolated cache directory.

    Returns:
        Cache directory path.
    """
    if "VIRTUAL_ENV" in os.environ:
        cache_dir = Path(os.environ["VIRTUAL_ENV"]) / ".ansible"
    elif isolated:
        cache_dir = project_dir / ".ansible"
    else:
        cache_dir = Path(os.environ.get("ANSIBLE_HOME", "~/.ansible")).expanduser()

    # Ensure basic folder structure exists so `ansible-galaxy list` does not
    # fail with: None of the provided paths were usable. Please specify a valid path with
    for name in ("roles", "collections"):  # pragma: no cover
        (cache_dir / name).mkdir(parents=True, exist_ok=True)

    return cache_dir



"""Tests for ansible_compat.prerun module."""

from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from _pytest.monkeypatch import MonkeyPatch

from ansible_compat.prerun import get_cache_dir


def test_get_cache_dir_relative() -> None:
    """Test behaviors of get_cache_dir."""
    relative_path = Path()
    abs_path = relative_path.resolve()
    assert get_cache_dir(relative_path) == get_cache_dir(abs_path)


def test_get_cache_dir_no_isolation_no_venv(monkeypatch: MonkeyPatch) -> None:
    """Test behaviors of get_cache_dir.

    Args:
        monkeypatch: Pytest fixture for monkeypatching
    """
    monkeypatch.delenv("VIRTUAL_ENV", raising=False)
    monkeypatch.delenv("ANSIBLE_HOME", raising=False)
    assert get_cache_dir(Path(), isolated=False) == Path("~/.ansible").expanduser()


def test_get_cache_dir_isolation_no_venv(monkeypatch: MonkeyPatch) -> None:
    """Test behaviors of get_cache_dir.

    Args:
        monkeypatch: Pytest fixture for monkeypatching
    """
    monkeypatch.delenv("VIRTUAL_ENV", raising=False)
    monkeypatch.delenv("ANSIBLE_HOME", raising=False)
    assert get_cache_dir(Path(), isolated=True) == Path() / ".ansible"
